@@ -3,5 +3,5 @@ from threading import RLock
 from typing import Any, ContextManager
 
 
-def get_lock(threadsafe: bool) -> ContextManager[Any]:
+def get_lock(threadsafe: bool | None = None) -> ContextManager[Any]:
     return RLock() if threadsafe else nullcontext()
